#include <Joystick.h>

// Create the joystick instance with 4 axes enabled.
// The parameters are: reportID, joystickType, buttonCount, hatSwitchCount, 
// xAxis, yAxis, zAxis, rAxis, rudder, throttle, accelerator, brake, steering, 
// etc. Here we only enable the four axes we need.
Joystick_ Joystick(
  JOYSTICK_DEFAULT_REPORT_ID, 
  JOYSTICK_TYPE_GAMEPAD, 
  0, 0,     // no buttons, no hat switches
  true, true, true, true,  // Enable X, Y, Z, and Rz axes
  false, false, false, false, false, false, false
);

void setup() {
  // Initialize the joystick library
  Joystick.begin();

  // Optionally, set the range for each axis. By default, the library uses -127 to 127.
  // If needed, you can customize using Joystick.setXAxisRange(min, max), etc.
}

void loop() {
  // Read the analog values from the four potentiometers
  int potX = analogRead(A0);  // e.g., left-right stick movement
  int potY = analogRead(A1);  // e.g., up-down stick movement
  int potZ = analogRead(A2);  // e.g., additional axis
  int potR = analogRead(A3);  // e.g., rudder control

  // Map the 10-bit ADC (0-1023) values to the joystick’s axis range.
  // In this example we map it to -127 to 127.
  int xValue = map(potX, 0, 1023, 0, 1023);
  int yValue = map(potY, 0, 1023, 0, 1023);
  int zValue = map(potZ, 0, 1023, 0, 1023);
  int rValue = map(potR, 0, 1023, 0, 1023);

  // Update the joystick axes
  Joystick.setXAxis(xValue);
  Joystick.setYAxis(yValue);
  Joystick.setZAxis(zValue);
  Joystick.setRxAxis(rValue);

  // A short delay to avoid flooding the USB bus with updates
  delay(10);
}
